@@ -1,14 +1,12 @@
 package Test::Class::Module::Build::Bundle::Contents;
 
-# $Id$
-
 use strict;
 use warnings;
 use Test::More;
 use File::Copy qw(cp);
 use Test::Exception;
 use File::Tempdir;
-use File::Stat;
+use File::stat;
 use File::Slurp;    #read_file
 use Env qw($TEST_VERBOSE);
 
